@@ -174,7 +174,7 @@ class _freeze_time(object):
         for mod_name, module in list(sys.modules.items()):
             if module is None:
                 continue
-            if mod_name.startswith('six.moves.'):
+            if mod_name.startswith(('six.moves.', 'django.utils.six.moves.')):
                 continue
             if hasattr(module, "__name__") and module.__name__ != 'datetime':
                 if hasattr(module, 'datetime') and module.datetime == real_datetime:
@@ -198,7 +198,7 @@ class _freeze_time(object):
         time.time = real_time
 
         for mod_name, module in list(sys.modules.items()):
-            if mod_name.startswith('six.moves.'):
+            if mod_name.startswith(('six.moves.', 'django.utils.six.moves.')):
                 continue
             if mod_name != 'datetime':
                 if hasattr(module, 'datetime') and module.datetime == FakeDatetime:
@@ -235,3 +235,19 @@ def freeze_time(time_to_freeze, tz_offset=0):
                          'datetime instance, but got type {0}.').format(type(time_to_freeze)))
 
     return _freeze_time(time_to_freeze, tz_offset)
+
+
+# Setup adapters for sqlite
+import sqlite3
+
+
+# These are copied from Python sqlite3.dbapi2
+def adapt_date(val):
+    return val.isoformat()
+
+
+def adapt_datetime(val):
+    return val.isoformat(" ")
+
+sqlite3.register_adapter(FakeDate, adapt_date)
+sqlite3.register_adapter(FakeDatetime, adapt_datetime)
